<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;
if ( ! class_exists( 'CDID' ) ) :

	/**
	 * Main CDID Class.
	 *
	 * @package		CDID
	 * @subpackage	Classes/CDID
	 * @since		1.0.0
	 * @author		ProiTs FZ LLC
	 */
	final class CDID {

		/**
		 * The real instance
		 *
		 * @access	private
		 * @since	1.0.0
		 * @var		object|CDID
		 */
		private static $instance;

		/**
		 * CDID helpers object.
		 *
		 * @access	public
		 * @since	1.0.0
		 * @var		object|CDID_Helpers
		 */
		public $helpers;

		/**
		 * CDID settings object.
		 *
		 * @access	public
		 * @since	1.0.0
		 * @var		object|CDID_Settings
		 */
		public $settings;

		/**
		 * CDID widget object.
		 *
		 * @access	public
		 * @since	1.0.0
		 * @var		object|CDID_Widget
		 */
		public $widget;

		/**
		 * CDID shortcode object.
		 *
		 * @access	public
		 * @since	1.0.0
		 * @var		object|CDID_Shortcode
		 */
		public $Shortcode;

		/**
		 * Throw error on object clone.
		 *
		 * Cloning instances of the class is forbidden.
		 *
		 * @access	public
		 * @since	1.0.0
		 * @return	void
		 */
		public function __clone() {
			_doing_it_wrong( __FUNCTION__, 'You are not allowed to clone this class.', '1.0.0' );
		}

		/**
		 * Disable unserializing of the class.
		 *
		 * @access	public
		 * @since	1.0.0
		 * @return	void
		 */
		public function __wakeup() {
			_doing_it_wrong( __FUNCTION__, 'You are not allowed to unserialize this class.', '1.0.0' );
		}

		/**
		 * Main CDID Instance.
		 *
		 * Insures that only one instance of CDID exists in memory at any one
		 * time. Also prevents needing to define globals all over the place.
		 *
		 * @access		public
		 * @since		1.0.0
		 * @static
		 * @return		object|CDID	The one true CDID
		 */
		public static function instance() {
			if ( ! isset( self::$instance ) && ! ( self::$instance instanceof CDID ) ) {
				self::$instance					= new CDID;
				self::$instance->base_hooks();
				self::$instance->includes();
				self::$instance->helpers		= new CDID_Helpers();
				self::$instance->settings		= new CDID_Settings();
				self::$instance->widget 		= new CDID_Widget();
				self::$instance->shortcode 		= new CDID_Shortcode();
				
				//Fire the plugin logic
				new CDID_Run();

				/**
				 * Fire a custom action to allow dependencies
				 * after the successful plugin setup
				 */
				do_action( 'CDID/plugin_loaded' );
			}

			return self::$instance;
		}

		/**
		 * Include required files.
		 *
		 * @access  private
		 * @since   1.0.0
		 * @return  void
		 */
		private function includes() {
			require_once CDID_PLUGIN_DIR . 'core/includes/classes/class-cdid-helpers.php';
			require_once CDID_PLUGIN_DIR . 'core/includes/classes/class-cdid-settings.php';
			require_once CDID_PLUGIN_DIR . 'core/includes/classes/class-cdid-widget.php';
			require_once CDID_PLUGIN_DIR . 'core/includes/classes/class-cdid-shortcode.php';

			require_once CDID_PLUGIN_DIR . 'core/includes/classes/class-cdid-run.php';
		}

		/**
		 * Add base hooks for the core functionality
		 *
		 * @access  private
		 * @since   1.0.0
		 * @return  void
		 */
		private function base_hooks() {
			add_action( 'plugins_loaded', array( self::$instance, 'load_textdomain' ) );
		}

		/**
		 * Loads the plugin language files.
		 *
		 * @access  public
		 * @since   1.0.0
		 * @return  void
		 */
		public function load_textdomain() {
			load_plugin_textdomain( 'CDID', FALSE, dirname( plugin_basename( CDID_PLUGIN_FILE ) ) . '/languages/' );
		}

	}

endif; // End if class_exists check.