<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Class CDID_Shortcode
 *
 * This class contains all of the shortcode related methods.
 *
 * @package		CDID
 * @subpackage	Classes/CDID_Shortcode
 * @author		ProiTs FZ LLC
 * @since		1.0.0
 */
class CDID_Shortcode{

	/**
	 * CDID site URL.
	 *
	 * @access	public
	 * @since	1.0.0
	 */
	public $CDID_url = 'https://cdid.online/';

	/**
	 * Register Shortcode with WordPress.
	 *
	 * @since	1.0.0
	 */

	function __construct() {
		add_shortcode( 'CDID_rank', array($this,'get_CDID_rank' ));
	}

	/**
	 * Get the site rank.
	 *
	 * @access	public
	 * @since	1.0.0
	 * @return	int -1,0 or the rank
	 */
	public function get_CDID_rank() {
		$rank			= get_option('cdid_rank');
		$last_update	= get_option('cdid_last_update');
		$date			= date("d/m");

		if($rank >  0 && $date == $last_update){
			return $rank;
		}

		$url		= $this->get_site_url();
		$api		= 'https://en6sporhrc41zxu.m.pipedream.net/?domainname=' . $url;
		//$api		= 'http://45.147.229.139:8089/api/v1/ranking/domain/?domainname=' . $url;

		$response	= wp_remote_get($api , array('timeout'=> 10,'httpversion' => '1.1'));
		if(is_wp_error( $response ) ) {
			return -1;
		}
		
		$body = wp_remote_retrieve_body($response);
		$body = json_decode($body ,true);

		if(isset($body['success']) && $body['RankingSite']  >  0 ){
			update_option('cdid_rank',$body['RankingSite']);
			update_option('cdid_last_update',$date);

			return $body['RankingSite'];
		}elseif (isset($body['success'])) {
			return 0; // for non registed sites
		}else {
			return -1; // for error in connection or getting response
		}
	}

	/**
	 * Get clear current website url
	 * @access	public
	 * @since	1.0.0
	 * @return	string
	 */
	public function get_site_url() {
		$url = get_option('cdid_site_url');
		if(!empty($url)){
			return $url;
		}

		$www = array('www.','ww2.');
		$url = site_url();
		$url = parse_url($url)['host'];
		$url = str_replace($www, "", $url);

		update_option('cdid_site_url',$url);
		return $url;
	}
}