<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Class CDID_Widget
 *
 * This class contains all of the plugin settings.
 * Here you can configure the whole plugin data.
 *
 * @package		CDID
 * @subpackage	Classes/CDID_Widget
 * @author		ProiTs FZ LLC
 * @since		1.0.0
 */
class CDID_Widget extends WP_Widget {

	/**
	 * CDID Website URL.
	 *
	 * @access	public
	 * @since	1.0.0
	 */
	public $CDID_url = 'https://cdid.online/';

	/**
	 * Defult color mode.
	 *
	 * @access	public
	 * @since	1.0.0
	 */
	public $defult_color_mode = 'colored';

	/**
	 * Register the widget with WordPress.
	 *
	 * @access	public
	 * @since	1.0.0
	 */

	function __construct() {
		parent::__construct(
			'cdid_rank', // Base ID
			esc_html__( 'CDID Widget', 'CDID' ), // Name
			array( 'description' => esc_html__( 'CDID Ranking Widget', 'CDID' ), ) // Args
		);
	}

	/**
	 * Front-end display of widget.
	 *
	 * @access	public
	 * @since	1.0.0
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {
		$data['args'] 		= $args;
		$data['instance']	= $instance;
		$data['response']	= do_shortcode('[CDID_rank]');
		$this->cdid_view('frontend-widget',$data);
	}

	/**
	 * cdid including views.
	 *
	 * @access	public
	 * @since	1.0.0
	 *
	 * @param string $view	part to be incuded.
	 * @param array $data 	data will be used in the part.
	 */
	function cdid_view($view,$data= array()){
		foreach ($data as $key => $value) {
			$$key =  $value;
		}
		include( CDID_PLUGIN_DIR . 'core/includes/plugin_parts/' . $view . '.php' );
	}

	/**
	 * Back-end widget form.
	 *
	 * @access	public
	 * @since	1.0.0
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {
		$data['color_mode'] = array(
			'value' => !empty( $instance['colormode'] ) ? esc_attr($instance['colormode']) : $this->defult_color_mode,
			'id'	=> esc_attr ($this->get_field_id('colormode')),
			'name'	=> $this->get_field_name('colormode'),
			'title' => __('Color Mode', 'CDID' )
		);
		
		$this->cdid_view('widget-backend-form',$data);
	}

	/**
	 * Sanitize and save new widget options.
	 *
	 * @access	public
	 * @since	1.0.0
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */

	public function update( $new_instance, $old_instance ) {
		// reset data evry new update to help in debuging and avoid problems in websites with old versions
		$this->reset_values();

		$instance = $old_instance;
		$instance['colormode'] = ( ! empty( $new_instance['colormode'] ) ) ? sanitize_text_field( $new_instance['colormode'] ) : $this->defult_color_mode;
		return $instance;
	}

	/**
	 * Reset Plugins values.
	 *
	 * @access	public
	 * @since	1.0.0
	 */
	public function reset_values() {
		update_option('cdid_rank','');
		update_option('cdid_last_update','');
		update_option('cdid_site_url','');
	}

}